
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2018 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef RG_COUNTDOWNBAR_H
#define RG_COUNTDOWNBAR_H

#include <QFrame>


class QWidget;
class QPaintEvent;


namespace Rosegarden
{



class CountdownBar : public QFrame
{
    Q_OBJECT
public:
    CountdownBar(QWidget *parent, int width, int height);
    void setPosition(int position);

protected:
    void paintEvent(QPaintEvent *e) override;

    int m_width;
    int m_height;
    int m_position;
};


}

#endif
